@@ -58,7 +58,7 @@ mod tests {
       info_destination,
       InfoDestination {
           guid_prefix: GuidPrefix {
-              entity_key: [0x01, 0x02, 0x6D, 0x3F,
+              bytes: [0x01, 0x02, 0x6D, 0x3F,
                           0x7E, 0x07, 0x00, 0x00,
                           0x01, 0x00, 0x00, 0x00]
           }
