@@ -1,5 +1,7 @@
 use crate::structure::guid::{EntityId, GuidPrefix, GUID};
 
+/// Trait for things that have a [`GUID`].
+///
 /// Base class for all RTPS entities. RTPS Entity represents the class of
 /// objects that are visible to other RTPS Entities on the network. As such,
 /// RTPS Entity objects have a globally-unique identifier (GUID) and can be
@@ -13,6 +15,6 @@ pub trait RTPSEntity {
     self.guid().entity_id
   }
   fn guid_prefix(&self) -> GuidPrefix {
-    self.guid().guid_prefix
+    self.guid().prefix
   }
 }
